@@ -17,6 +17,8 @@ class DetailsWindow(hildon.StackableWindow):
 
         self.osmMapa.set_autorotate_for_object(self)
 
+        self.details_share = ""
+
         #self.set_default_size(500, 500)
         self.set_title("Details")
 
@@ -32,10 +34,9 @@ class DetailsWindow(hildon.StackableWindow):
         tlldbox = gtk.VBox()
 
         tlldbox.pack_start( self.get_label("<big>%s</big>" % point[3]) , False)
+        self.details_share = "%s " % point[3]
 
 
-
-        label = gtk.Label( "Lat: %f" % point[0] )
         tlldbox.pack_start( self.get_label(
             "<small>%s</small>" %  self.osmMapa.distance_to_string( self.osmMapa.distance( point[0], point[1]) )
             )
@@ -58,17 +59,24 @@ class DetailsWindow(hildon.StackableWindow):
                             break
             except:
                 pass
+            
+        self.details_share = "%slat/lon: %f,%f " % (self.details_share, point[0], point[1])
+
 
         tlldbox.pack_start( self.get_label("Latitude: <small>%f</small>" % point[0]), False)
         tlldbox.pack_start( self.get_label("Longitude: <small>%f</small>" % point[1]), False)
         tlldbox.pack_start( self.get_label("Point from : <small>%s</small>" % point[2]), False)
 
 
+        self.bt_hbox = gtk.HBox()
 
         if point[2] == "Google - places":
             powerBy = gtk.Image()
             powerBy.set_from_file("./plugins/powered-by-google-on-black.png")
             tlldbox.pack_start( powerBy, False)
+        else:
+            if self.osmMapa.send_to_contact_present():
+                self.bt_hbox.pack_end(self.osmMapa.send_to_contact_dialog(self.details_share), False)
 
 
         lrbox.pack_start( tlldbox, True)
@@ -89,12 +97,11 @@ class DetailsWindow(hildon.StackableWindow):
         vbox0.pack_start( panel, True)
 
 
-        bt_hbox = gtk.HBox()
 
         bt_mapa = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,"Mapa")
         bt_mapa.connect("clicked", self.on_mapa)
-        bt_hbox.pack_start( bt_mapa, True)
+        self.bt_hbox.pack_start( bt_mapa, True)
 
 
 
@@ -103,16 +110,18 @@ class DetailsWindow(hildon.StackableWindow):
             bt_poi = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,"POI")
             bt_poi.connect("clicked",self.on_add_as_poi,point[0],point[1])
-            bt_hbox.pack_start( bt_poi, True)
+            self.bt_hbox.pack_start( bt_poi, True)
 
         if self.CONFIG['Google - routesearch']:
             bt_route = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,"Route")
             bt_route.connect("clicked",self.on_route_to_it,point[0],point[1])
-            bt_hbox.pack_start( bt_route, True)
+            self.bt_hbox.pack_start( bt_route, True)
+            
+        
 
 
-        vbox.pack_start(bt_hbox,False)
+        vbox.pack_start(self.bt_hbox,False)
 
         self.vbox = gtk.VBox()
         self.add(self.vbox)
@@ -142,12 +151,21 @@ class DetailsWindow(hildon.StackableWindow):
 
                 bt_phone = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,"%s" % ref_downloader.ref_result[2])
+                
+                self.details_share = "%stel: %s; %s" % (self.details_share, ref_downloader.ref_result[2], ref_downloader.ref_result[1])
+                
                 bt_phone.connect("clicked",self.on_call_clicked, ref_downloader.ref_result[2] )
                 hbox.pack_start( bt_phone, True)
 
                 tlldbox.pack_start( hbox, False)
 
                 tlldbox.show_all()
+                
+                
+                if self.osmMapa.send_to_contact_present():
+                    self.bt_hbox.pack_start(self.osmMapa.send_to_contact_dialog(self.details_share), False)
+
+                
             except Exception, e:
                 print "add reference error",e
 
