@@ -141,6 +141,19 @@ class MainMenuDialog( hildon.StackableWindow ):
         bt_about.connect("clicked",self.on_bt_about)
         hbox.pack_start(bt_about, False)
 
+
+        bt_show = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
+        bt_show.set_label("welcome screen")
+        try:
+            if self.CONFIG['welcome_screen']:
+                bt_show.set_active( self.CONFIG['welcome_screen'] )
+        except:
+            self.CONFIG['welcome_screen'] = 1
+            bt_show.set_active( self.CONFIG['welcome_screen'] )
+            pass
+        bt_show.connect("clicked", self.on_bt_show)
+        hbox.pack_start(bt_show, False)
+
         mvbox.pack_start(hbox,False)
 
 
@@ -161,7 +174,8 @@ class MainMenuDialog( hildon.StackableWindow ):
         self.show_all()
 
 
-
+    def on_bt_show(self,w):
+        self.CONFIG['welcome_screen'] = w.get_active()
 
     def on_close(self,widget=None):
         self.destroy()
