@@ -1,4 +1,5 @@
 import gtk
+import hildon
 
 class google_link:
 
@@ -13,12 +14,17 @@ class google_link:
         lon = self.osmMapa.osm.props.longitude
         zoom = self.osmMapa.osm.props.zoom
 
-        en_location = gtk.Entry()
-        en_location.set_text( "http://maps.google.com/maps?z=%i&q=loc:%f+%f" %
-                              (zoom,lat,lon)
-                              )
+        hbox = gtk.HBox()
 
-        return en_location
+        en_location = gtk.Entry()
+        url = "http://maps.google.com/maps?z=%i&q=loc:%f+%f" % (zoom,lat,lon )
+        en_location.set_text( url )
+        hbox.pack_start(en_location, True)
+
+        if self.osmMapa.send_to_contact_present():
+            hbox.pack_start(self.osmMapa.send_to_contact_dialog(url), False)
+
+        return hbox
 
     def get_name(self):
         return "Google - link"
