@@ -42,6 +42,7 @@ from h_config_sl import *
 from h_UI_searchDialog import *
 from h_UI_mainMenuDialog import *
 from h_UI_detailsWindow import *
+from h_UI_welcomeScreen import *
 
 try:
     from h_UI_selectContact import *
@@ -161,9 +162,9 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
         self.pb_min = cairo.ImageSurface.create_from_png( './imgs/i_min.png' )
         self.pb_gps_on = cairo.ImageSurface.create_from_png( './imgs/i_gps_on.png' )
         self.pb_gps = cairo.ImageSurface.create_from_png( './imgs/i_gps.png' )
-        self.pb_menu = cairo.ImageSurface.create_from_png( './imgs/ico_work_64_64.png' )
+        self.pb_menu = cairo.ImageSurface.create_from_png( './imgs/ico_config2_64_64.png' )
 
-        self.pb_find = cairo.ImageSurface.create_from_png( './imgs/ico_find_48_48.png' )
+        self.pb_find = cairo.ImageSurface.create_from_png( './imgs/ico_find2_48_48.png' )
         self.pb_clean = cairo.ImageSurface.create_from_png( './imgs/ico_clean_48_48.png' )
         #self.show_find_results
 
@@ -278,11 +279,11 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                 self.osmMapa.zoom_out_clicked(None)
             elif len(self.osmMapa.find_plugins) >0 and gdkeventbutton.y>(self.size[1]-160) and  gdkeventbutton.y<(self.size[1]-105):
                 print "bt search"
-                dialog = SearchDialog(self.osmMapa, CONFIG)
+                self.osmMapa.build_search()
 
             elif gdkeventbutton.y>(self.size[1]-100) and  gdkeventbutton.y<(self.size[1]-34):
                 print "bt menu"
-                dialog = MainMenuDialog(self.osmMapa, CONFIG, maps_source,autorotate, FremantleRotation)
+                self.osmMapa.build_mainMenu()
                 #dialog.run()
                 #dialog.destroy()
                 #print "response from dialog [",res,"]"
@@ -476,15 +477,44 @@ class UI(hildon.StackableWindow):
 
     def get_config(self):
         return CONFIG
+    def set_config(self,str, val):
+        CONFIG[str] = val
     def get_version(self):
         return version
 
 
+    def plugin_present(self,plug_name):
+        tr = 0
+        if CONFIG[plug_name] == 0:
+            return tr
 
+        for p in self.plugins_list:
+            if p[1] == plug_name:
+                return 1
 
+        return tr
+    def get_plugin(self, str):
+        for p in self.plugins_list:
+            if str == p[1]:
+                return p[0]
 
+    def build_mainMenu(self):
+        dialog = MainMenuDialog(self, CONFIG, maps_source,autorotate, FremantleRotation)
 
+    def build_search(self):
+        dialog = SearchDialog(self, CONFIG)
 
+    def build_route(self):
+        plug = self.get_plugin("Google - routesearch")
+
+        w = hildon.StackableWindow()
+        self.set_autorotate_for_object(w)
+        w.set_title( plug.get_name() )
+        v = gtk.VBox()
+        w2 = plug.get_menu_widgets(w)
+        v.pack_start(w2, True)
+        w.add( v )
+        w.show_all()
 
 
 
@@ -510,8 +540,11 @@ class UI(hildon.StackableWindow):
 
         d.vbox.pack_start( gtk.Label("Send to: %s"%telNr), False)
 
-        text = gtk.Entry()
-        text.set_text( str_to_send)
+        text = gtk.TextView()
+        text.set_size_request(240, 240)
+        tb = text.get_buffer()
+        tb.set_text( str_to_send )
+        text.set_buffer( tb )
         d.vbox.pack_start( text, True)
 
         bt_send = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
@@ -524,9 +557,11 @@ class UI(hildon.StackableWindow):
         d.destroy()
 
     def send_to_contact_step3(self, w, number, text, dialog):
-        message = text.get_text()
+        tb = text.get_buffer()
+        message = tb.get_text( tb.get_start_iter(), tb.get_end_iter() )
 
         cmd = "smssend -s -v 167 -m \"%s\" -n %s &" % (message.replace("\"", "'"), number)
+        print "cmd [[%s]]" % cmd
         os.system(cmd)
 
 
@@ -1137,7 +1172,8 @@ class UI(hildon.StackableWindow):
                         print "UI map_release ERROR:", e
 
 
-
+    def welcomeScreenInit(self):
+        ws = WelcomeScreen(self,CONFIG)
 
 
 
@@ -1251,6 +1287,12 @@ if __name__ == "__main__":
         CONFIG['lon'] = 16.970615
         u.ben_iter_func()
 
+    try:
+        if CONFIG['welcome_screen']:
+            u.welcomeScreenInit()
+    except:
+         u.welcomeScreenInit()
+
     if os.name == "nt": gtk.gdk.threads_enter()
     gtk.main()
     if os.name == "nt": gtk.gdk.threads_leave()
